==> ubuntu_localizations-0.3.1.tar.gz: lib/src/l10n/ubuntu_localizations_ar.dart <==
import 'ubuntu_localizations.dart';

/// The translations for Arabic (`ar`).
class UbuntuLocalizationsAr extends UbuntuLocalizations {
  UbuntuLocalizationsAr([String locale = 'ar']) : super(locale);

  @override
  String get countryCode => 'EG';

  @override
  String get languageName => 'عربي';

  @override
  String get backAction => 'الرجوع للخلف';

  @override
  String get continueAction => 'المواصلة';

  @override
  String get strongPassword => 'كلمة مرور قوية';

  @override
  String get fairPassword => 'كلمة مرور مقبولة';

  @override
  String get goodPassword => 'كلمة مرور جيدة';

  @override
  String get weakPassword => 'كلمة مرور ضعيفة';

  @override
  String get altKey => 'Alt';

  @override
  String get controlKey => 'Control';

  @override
  String get metaKey => 'Meta';

  @override
  String get shiftKey => 'Shift';

  @override
  String get aboutLabel => 'حول';

  @override
  String get addLabel => 'Add';

  @override
  String get allLabel => 'All';

  @override
  String get applyLabel => 'Apply';

  @override
  String get ascendingLabel => 'Ascending';

  @override
  String get backLabel => 'Back';

  @override
  String get boldLabel => 'Bold';

  @override
  String get bottomLabel => 'Bottom';

  @override
  String get cancelLabel => 'الغاء';

  @override
  String get centerLabel => 'Center';

  @override
  String get clearLabel => 'Clear';

  @override
  String get closeLabel => 'Close';

  @override
  String get colorLabel => 'Color';

  @override
  String get connectLabel => 'Connect';

  @override
  String get continueLabel => 'Continue';

  @override
  String get copyLabel => 'Copy';

  @override
  String get createLabel => 'Create';

  @override
  String get cutLabel => 'Cut';

  @override
  String get decreaseLabel => 'Decrease';

  @override
  String get deleteLabel => 'Delete';

  @override
  String get descendingLabel => 'Descending';

  @override
  String get discardLabel => 'Discard';

  @override
  String get disconnectLabel => 'Disconnect';

  @override
  String get doneLabel => 'Done';

  @override
  String get downloadLabel => 'Download';

  @override
  String get editLabel => 'Edit';

  @override
  String get enterLabel => 'Enter';

  @override
  String get errorLabel => 'Error';

  @override
  String get executeLabel => 'Execute';

  @override
  String get exitLabel => 'Exit';

  @override
  String get fileLabel => 'File';

  @override
  String get fillLabel => 'Fill';

  @override
  String get findLabel => 'Find';

  @override
  String get firstLabel => 'First';

  @override
  String get fontLabel => 'Font';

  @override
  String get forwardLabel => 'Forward';

  @override
  String get fullscreenLabel => 'Fullscreen';

  @override
  String get goBackLabel => 'Go Back';

  @override
  String get helpLabel => 'Help';

  @override
  String get homeLabel => 'Home';

  @override
  String get importLabel => 'Import';

  @override
  String get increaseLabel => 'Increase';

  @override
  String get indexLabel => 'Index';

  @override
  String get informationLabel => 'Information';

  @override
  String get insertLabel => 'Insert';

  @override
  String get italicLabel => 'Italic';

  @override
  String get landscapeLabel => 'Landscape';

  @override
  String get lastLabel => 'Last';

  @override
  String get leaveLabel => 'Leave';

  @override
  String get leftLabel => 'Left';

  @override
  String get mediaLabel => 'Media';

  @override
  String get networkLabel => 'Network';

  @override
  String get newLabel => 'New';

  @override
  String get nextLabel => 'Next';

  @override
  String get noLabel => 'لا';

  @override
  String get noneLabel => 'None';

  @override
  String get normalLabel => 'Normal';

  @override
  String get okLabel => 'موافق';

  @override
  String get openLabel => 'Open';

  @override
  String get pasteLabel => 'Paste';

  @override
  String get pauseLabel => 'Pause';

  @override
  String get playLabel => 'Play';

  @override
  String get portraitLabel => 'Portrait';

  @override
  String get preferencesLabel => 'Preferences';

  @override
  String get previousLabel => 'Previous';

  @override
  String get printLabel => 'Print';

  @override
  String get printPreviewLabel => 'Print Preview';

  @override
  String get propertiesLabel => 'Properties';

  @override
  String get questionLabel => 'Question';

  @override
  String get quitLabel => 'Quit';

  @override
  String get recordLabel => 'Record';

  @override
  String get redoLabel => 'Redo';

  @override
  String get refreshLabel => 'Refresh';

  @override
  String get removeLabel => 'Remove';

  @override
  String get renameLabel => 'Rename';

  @override
  String get resetLabel => 'Reset';

  @override
  String get restoreLabel => 'Restore';

  @override
  String get retryLabel => 'Retry';

  @override
  String get revertLabel => 'Revert';

  @override
  String get rewindLabel => 'Rewind';

  @override
  String get rightLabel => 'Right';

  @override
  String get saveAsLabel => 'Save As';

  @override
  String get saveLabel => 'Save';

  @override
  String get searchLabel => 'Search';

  @override
  String get selectAllLabel => 'Select All';

  @override
  String get selectLabel => 'Select';

  @override
  String get sendLabel => 'Send';

  @override
  String get skipLabel => 'Skip';

  @override
  String get sortLabel => 'Sort';

  @override
  String get stopLabel => 'Stop';

  @override
  String get strikeThroughLabel => 'Strike Through';

  @override
  String get submitLabel => 'Submit';

  @override
  String get topLabel => 'Top';

  @override
  String get undoLabel => 'Undo';

  @override
  String get updateLabel => 'Update';

  @override
  String get upLabel => 'Up';

  @override
  String get viewLabel => 'View';

  @override
  String get warningLabel => 'Warning';

  @override
  String get windowLabel => 'Window';

  @override
  String get yesLabel => 'نعم';

  @override
  String get zoomInLabel => 'Zoom In';

  @override
  String get zoomOutLabel => 'Zoom Out';

  @override
  String get byte => 'B';

  @override
  String get kilobyte => 'kB';

  @override
  String get megabyte => 'م.ب';

  @override
  String get gigabyte => 'GB';

  @override
  String get terabyte => 'TB';

  @override
  String get petabyte => 'PB';
}

==> ubuntu_localizations-0.3.4.tar.gz: lib/src/l10n/ubuntu_localizations_ar.dart <==
import 'ubuntu_localizations.dart';

/// The translations for Arabic (`ar`).
class UbuntuLocalizationsAr extends UbuntuLocalizations {
  UbuntuLocalizationsAr([String locale = 'ar']) : super(locale);

  @override
  String get countryCode => 'EG';

  @override
  String get languageName => 'عربي';

  @override
  String get backAction => 'الرجوع للخلف';

  @override
  String get continueAction => 'المواصلة';

  @override
  String get strongPassword => 'كلمة مرور قوية';

  @override
  String get fairPassword => 'كلمة مرور مقبولة';

  @override
  String get goodPassword => 'كلمة مرور جيدة';

  @override
  String get weakPassword => 'كلمة مرور ضعيفة';

  @override
  String get altKey => 'Alt';

  @override
  String get controlKey => 'Control';

  @override
  String get metaKey => 'Meta';

  @override
  String get shiftKey => 'Shift';

  @override
  String get aboutLabel => 'حول';

  @override
  String get addLabel => 'Add';

  @override
  String get allLabel => 'All';

  @override
  String get applyLabel => 'Apply';

  @override
  String get ascendingLabel => 'Ascending';

  @override
  String get backLabel => 'Back';

  @override
  String get boldLabel => 'Bold';

  @override
  String get bottomLabel => 'Bottom';

  @override
  String get cancelLabel => 'الغاء';

  @override
  String get centerLabel => 'Center';

  @override
  String get clearLabel => 'Clear';

  @override
  String get closeLabel => 'Close';

  @override
  String get colorLabel => 'Color';

  @override
  String get connectLabel => 'اتّصل';

  @override
  String get continueLabel => 'Continue';

  @override
  String get copyLabel => 'Copy';

  @override
  String get createLabel => 'Create';

  @override
  String get cutLabel => 'Cut';

  @override
  String get decreaseLabel => 'Decrease';

  @override
  String get deleteLabel => 'Delete';

  @override
  String get descendingLabel => 'Descending';

  @override
  String get discardLabel => 'Discard';

  @override
  String get disconnectLabel => 'Disconnect';

  @override
  String get doneLabel => 'Done';

  @override
  String get downloadLabel => 'Download';

  @override
  String get editLabel => 'Edit';

  @override
  String get enterLabel => 'Enter';

  @override
  String get errorLabel => 'Error';

  @override
  String get executeLabel => 'Execute';

  @override
  String get exitLabel => 'Exit';

  @override
  String get fileLabel => 'File';

  @override
  String get fillLabel => 'Fill';

  @override
  String get findLabel => 'Find';

  @override
  String get firstLabel => 'First';

  @override
  String get fontLabel => 'Font';

  @override
  String get forwardLabel => 'Forward';

  @override
  String get fullscreenLabel => 'Fullscreen';

  @override
  String get goBackLabel => 'Go Back';

  @override
  String get helpLabel => 'Help';

  @override
  String get homeLabel => 'Home';

  @override
  String get importLabel => 'Import';

  @override
  String get increaseLabel => 'Increase';

  @override
  String get indexLabel => 'Index';

  @override
  String get informationLabel => 'Information';

  @override
  String get insertLabel => 'Insert';

  @override
  String get italicLabel => 'Italic';

  @override
  String get landscapeLabel => 'Landscape';

  @override
  String get lastLabel => 'Last';

  @override
  String get leaveLabel => 'Leave';

  @override
  String get leftLabel => 'Left';

  @override
  String get mediaLabel => 'Media';

  @override
  String get networkLabel => 'Network';

  @override
  String get newLabel => 'New';

  @override
  String get nextLabel => 'Next';

  @override
  String get noLabel => 'لا';

  @override
  String get noneLabel => 'None';

  @override
  String get normalLabel => 'Normal';

  @override
  String get okLabel => 'موافق';

  @override
  String get openLabel => 'Open';

  @override
  String get pasteLabel => 'Paste';

  @override
  String get pauseLabel => 'Pause';

  @override
  String get playLabel => 'Play';

  @override
  String get portraitLabel => 'Portrait';

  @override
  String get preferencesLabel => 'Preferences';

  @override
  String get previousLabel => 'Previous';

  @override
  String get printLabel => 'Print';

  @override
  String get printPreviewLabel => 'Print Preview';

  @override
  String get propertiesLabel => 'Properties';

  @override
  String get questionLabel => 'Question';

  @override
  String get quitLabel => 'Quit';

  @override
  String get recordLabel => 'Record';

  @override
  String get redoLabel => 'Redo';

  @override
  String get refreshLabel => 'Refresh';

  @override
  String get removeLabel => 'Remove';

  @override
  String get renameLabel => 'Rename';

  @override
  String get resetLabel => 'Reset';

  @override
  String get restartLabel => 'إعادة تشغيل';

  @override
  String get restoreLabel => 'Restore';

  @override
  String get retryLabel => 'Retry';

  @override
  String get revertLabel => 'يرجع';

  @override
  String get rewindLabel => 'Rewind';

  @override
  String get rightLabel => 'Right';

  @override
  String get saveAsLabel => 'Save As';

  @override
  String get saveLabel => 'Save';

  @override
  String get searchLabel => 'Search';

  @override
  String get selectAllLabel => 'Select All';

  @override
  String get selectLabel => 'Select';

  @override
  String get sendLabel => 'Send';

  @override
  String get skipLabel => 'Skip';

  @override
  String get sortLabel => 'Sort';

  @override
  String get stopLabel => 'Stop';

  @override
  String get strikeThroughLabel => 'Strike Through';

  @override
  String get submitLabel => 'Submit';

  @override
  String get topLabel => 'Top';

  @override
  String get undoLabel => 'Undo';

  @override
  String get updateLabel => 'Update';

  @override
  String get upLabel => 'Up';

  @override
  String get viewLabel => 'View';

  @override
  String get warningLabel => 'Warning';

  @override
  String get windowLabel => 'Window';

  @override
  String get yesLabel => 'نعم';

  @override
  String get zoomInLabel => 'Zoom In';

  @override
  String get zoomOutLabel => 'Zoom Out';

  @override
  String get byte => 'B';

  @override
  String get kilobyte => 'kB';

  @override
  String get megabyte => 'م.ب';

  @override
  String get gigabyte => 'GB';

  @override
  String get terabyte => 'TB';

  @override
  String get petabyte => 'PB';
}
